Major rework of the directory structure and the entire build system.
 -Erik
diff --git a/tests/testcases b/tests/testcases
index 2aad9b6..2c28bf3 100644
--- a/tests/testcases
+++ b/tests/testcases
@@ -199,7 +199,7 @@
 
 
 # ifconfig
-# requires BB_FEATURE_IFCONFIG_STATUS
+# requires CONFIG_FEATURE_IFCONFIG_STATUS
 ifconfig
 #ifconfig -a
 #ifconfig eth0
diff --git a/tests/tester.sh b/tests/tester.sh
index a767c6c..09ba750 100755
--- a/tests/tester.sh
+++ b/tests/tester.sh
@@ -10,7 +10,7 @@
 BUSYBOX=../busybox
 TESTCASES=testcases
 LOGFILE=tester.log
-BB_OUT=bb.out
+CONFIG_OUT=bb.out
 GNU_OUT=gnu.out
 SETUP=""
 CLEANUP=""
@@ -25,7 +25,7 @@
 		p) BUSYBOX=$OPTARG; ;;
 		t) TESTCASES=$OPTARG; ;;
 		l) LOGFILE=$OPTARG; ;;
-#		b) BB_OUT=$OPTARG; ;;
+#		b) CONFIG_OUT=$OPTARG; ;;
 #		g) GNU_OUT=$OPTARG; ;;
 		s) SETUP=$OPTARG; ;;
 		c) CLEANUP=$OPTARG; ;;
@@ -59,7 +59,7 @@
 	echo "BUSYBOX=$BUSYBOX"
 	echo "TESTCASES=$TESTCASES"
 	echo "LOGFILE=$LOGFILE"
-	echo "BB_OUT=$BB_OUT"
+	echo "CONFIG_OUT=$CONFIG_OUT"
 	echo "GNU_OUT=$GNU_OUT"
 	echo "SETUP=$SETUP"
 	echo "CLEANUP=$CLEANUP"
@@ -129,14 +129,14 @@
 
 				# execute line using busybox programs
 				[ $DEBUG -ge 2 ] && echo "testing: $line" | tee -a $LOGFILE
-				sh -c "$line" > $BB_OUT
+				sh -c "$line" > $CONFIG_OUT
 
 				# see if they match
-				diff -q $BB_OUT $GNU_OUT > /dev/null
+				diff -q $CONFIG_OUT $GNU_OUT > /dev/null
 				if [ $? -eq 1 ]
 				then
 					[ $DEBUG -ge 1 ] && echo "FAILED: $line" | tee -a $LOGFILE
-					diff -u $BB_OUT $GNU_OUT >> $LOGFILE 
+					diff -u $CONFIG_OUT $GNU_OUT >> $LOGFILE 
 				fi
 			fi
 		fi
@@ -147,7 +147,7 @@
 
 
 # do normal cleanup
-[ "$KEEPTMPFILES" = "no" ] && rm -f $BB_OUT $GNU_OUT
+[ "$KEEPTMPFILES" = "no" ] && rm -f $CONFIG_OUT $GNU_OUT
 
 
 # do extra cleanup (if any)
diff --git a/tests/multibuild.pl b/tests/multibuild.pl
index 94930bd..a3e49a6 100755
--- a/tests/multibuild.pl
+++ b/tests/multibuild.pl
@@ -12,13 +12,13 @@
 
 $logfile = "multibuild.log";
 
 # How to handle all the BB_FEATURE_FOO lines
 if ($ARGV[0] eq "-all" ) { shift(@ARGV); $choice="all"; }
 if ($ARGV[0] eq "-none") { shift(@ARGV); $choice="none"; }
 # neither means, leave that part of Config.h alone
 
 # Support building from pristine source
-$make_opt = "-f $ARGV[0]/Makefile BB_SRC_DIR=$ARGV[0]" if ($ARGV[0] ne "");
+$make_opt = "-f $ARGV[0]/Makefile CONFIG_SRC_DIR=$ARGV[0]" if ($ARGV[0] ne "");
 
 # Move the config file to a safe place
 -e "Config.h.orig" || 0==system("mv -f Config.h Config.h.orig") || die;
@@ -38,7 +38,7 @@
 		$trailer .= $_;
 	} else {
 		$in_trailer=1 if /End of Applications List/;
-		if (/^\/*#define BB_([A-Z0-9_]*)/) {
+		if (/^\/*#define CONFIG_([A-Z0-9_]*)/) {
 			push @apps, $1;
 		}
 	}
@@ -50,7 +50,7 @@
 for $a (@apps) {
 	# print "Testing build of applet $a ...\n";
 	open (O, ">Config.h") || die;
-	print O "#define BB_$a\n", $trailer;
+	print O "#define CONFIG_$a\n", $trailer;
 	close O;
 	system("echo -e '\n***\n$a\n***' >>$logfile");
 	# With a fast computer and 1-second resolution on file timestamps, this
@@ -12,13 +12,13 @@
 $logfile = "multibuild.log";
 
-# How to handle all the BB_FEATURE_FOO lines
+# How to handle all the CONFIG_FEATURE_FOO lines
 if ($ARGV[0] eq "-all" ) { shift(@ARGV); $choice="all"; }
 if ($ARGV[0] eq "-none") { shift(@ARGV); $choice="none"; }
diff --git a/tests/multifeat.pl b/tests/multifeat.pl
index adcb30b..875b4a2 100755
--- a/tests/multifeat.pl
+++ b/tests/multifeat.pl
@@ -11,14 +11,14 @@
 
 $logfile = "multifeat.log";
 
 # How to handle all the BB_APPLET lines
 # (most thorough testing occurs when you call it with the -all switch)
 if ($ARGV[0] eq "-all" ) { shift(@ARGV); $choice="all"; }
 if ($ARGV[0] eq "-none") { shift(@ARGV); $choice="none"; }
 # neither means, leave that part of Config.h alone
 
 # Support building from pristine source
-$make_opt = "-f $ARGV[0]/Makefile BB_SRC_DIR=$ARGV[0]" if ($ARGV[0] ne "");
+$make_opt = "-f $ARGV[0]/Makefile CONFIG_SRC_DIR=$ARGV[0]" if ($ARGV[0] ne "");
 
 # Move the config file to a safe place
 -e "Config.h.orig" || 0==system("mv -f Config.h Config.h.orig") || die;
@@ -42,7 +42,7 @@
 		}
 	}
 	elsif ($in_features) {
-		if (/^\/*#define BB_FEATURE_([A-Z0-9_]*)/) {
+		if (/^\/*#define CONFIG_FEATURE_([A-Z0-9_]*)/) {
 			push @features, $1;
 		}
 		if (/End of Features List/) {
@@ -60,7 +60,7 @@
 for $f (@features) {
 	# print "Testing build with feature $f ...\n";
 	open (O, ">Config.h") || die;
-	print O $header, "#define BB_FEATURE_$f\n", $trailer;
+	print O $header, "#define CONFIG_FEATURE_$f\n", $trailer;
 	close O;
 	system("echo -e '\n***\n$f\n***' >>$logfile");
 	# With a fast computer and 1-second resolution on file timestamps, this
@@ -11,14 +11,14 @@
 $logfile = "multifeat.log";
 
-# How to handle all the BB_APPLET lines
+# How to handle all the CONFIG_APPLET lines
 # (most thorough testing occurs when you call it with the -all switch)
 if ($ARGV[0] eq "-all" ) { shift(@ARGV); $choice="all"; }